ggwidth-package: ggwidth: Publication-Quality 'ggplot2' Geom Width

ggwidth-packageR Documentation

ggwidth: Publication-Quality 'ggplot2' Geom Width

Description

logo

Width helper functions for publication-quality 'ggplot2' visualisation. These functions make it easier to create geoms such as bars that have a consistent width appearance across plots.

Author(s)

Maintainer: David Hodge davidhodge931@gmail.com (ORCID) [copyright holder]

Authors:

See Also

Useful links:


ggwidth documentation built on Sept. 11, 2026, 1:06 a.m.