set_equiwidth: Set a global equiwidth

View source: R/set-equiwidth.R

set_equiwidthR Documentation

Set a global equiwidth

Description

Sets a global default for the equiwidth argument in get_width(). This is the scaling factor that controls the width appearance. All subsequent calls to get_width() use this value when equiwidth = NULL, and fall back to 1.

Usage

set_equiwidth(equiwidth = 1)

Arguments

equiwidth

Numeric. Multiplicative factor that controls the width appearance. A value of 1 is the default. Increase to make a wider appearance, and decrease to make a thinner appearance.

Value

No return value. Side effects only.

See Also

get_width()

Examples

set_equiwidth(1)
set_equiwidth(0.75)
set_equiwidth(1.33)

ggwidth documentation built on May 4, 2026, 9:09 a.m.