| ggwidth-package | R Documentation |
Width helper functions for publication-quality 'ggplot2' visualisation. These functions make it easier to create geoms such as bars that have a consistent width appearance across plots.
Maintainer: David Hodge davidhodge931@gmail.com (ORCID) [copyright holder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.