Sets a global default for the equiwidth argument in get_width().
This is the scaling factor that controls the width appearance.
All subsequent calls to get_width() use this value when
equiwidth = NULL, and fall back to 1.
Sets a global default for the equiwidth argument in get_width().
This is the scaling factor that controls the width appearance.
All subsequent calls to get_width() use this value when
equiwidth = NULL, and fall back to 1.