View source: R/set-equiwidth.R
| set_equiwidth | R Documentation |
Sets a global default for the equiwidth argument in get_width().
This is the scaling factor that controls the width appearance.
All subsequent calls to get_width() use this value when
equiwidth = NULL, and fall back to 1.
set_equiwidth(equiwidth = 1)
equiwidth |
Numeric. Multiplicative factor that controls the width appearance.
A value of |
No return value. Side effects only.
get_width()
set_equiwidth(1)
set_equiwidth(0.75)
set_equiwidth(1.33)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.